***********************************************************************************************;
**** This program modified by Aandy Lake 05.03;
**** Information Management Services Inc.;
**** lakea@imsweb.com;
**** This program is an example of how to use the record uniqueness SAS macro;
***********************************************************************************************;

filename indata "filename location";       * Insert directory and file name of the data file being analyzed;

  proc format;
    value age
      0 = "00 years   "
      1 = "01-04 years"
      2 = "05-09 years"
      3 = "10-14 years"
      4 = "15-19 years"
      5 = "20-24 years"
      6 = "25-29 years"
      7 = "30-34 years"
      8 = "35-39 years"
      9 = "40-44 years"
      10= "45-49 years"
      11= "50-54 years"
      12= "55-59 years"
      13= "60-64 years"
      14= "65-69 years"
      15= "70-74 years"
      16= "75-79 years"
      17= "80-84 years"
      18= "85+ years  ";

    value age_10yr
      0-2 = "00-09 years"
      3-4 = "10-19 years"
      5-6 = "20-29 years"
      7-8 = "30-39 years"
      9-10 = "40-49 years"
      11-12= "50-59 years"
      13-14= "60-69 years"
      15-16= "70-79 years"
      17-18= "80+ years";

    value sex            
      1 = "Male"         
      2 = "Female"; 

    value yr             
      195 = "1995"       
      196 = "1996"       
      197 = "1997"       
      198 = "1998"       
      199 = "1999"       
      200 = "2000"       
      201 = "2001";
                    
  value site
    1="Lip                                               "
    2="Tongue                                            "
    3="Salivary Gland                                    "
    4="Floor of Mouth                                    "
    5="Gum and Other Mouth                               "
    6="Nasopharynx                                       "
    7="Tonsil                                            "
    8="Oropharynx                                        "
    9="Hypopharynx                                       "
    10="Other Oral Cavity and Pharynx                    "
    11="Esophagus                                        "
    12="Stomach                                          "
    13="Small Intestine                                  "
    15="Cecum                                            "
    16="Appendix                                         "
    17="Ascending Colon                                  "
    18="Hepatic Flexure                                  "
    19="Transverse Colon                                 "
    20="Splenic Flexure                                  "
    21="Descending Colon                                 "
    22="Sigmoid Colon                                    "
    23="Large Intestine, NOS                             "
    25="Rectosigmoid Junction                            "
    26="Rectum                                           "
    27="Anus, Anal Canal and Anorectum                   "
    29="Liver                                            "
    30="Intrahepatic Bile Duct                           "
    31="Gallbladder                                      "
    32="Other Biliary                                    "
    33="Pancreas                                         "
    34="Retroperitoneum                                  "
    35="Peritoneum, Omentum and Mesentery                "
    36="Other Digestive Organs                           "
    37="Nose, Nasal Cavity and Middle Ear                "
    38="Larynx                                           "
    39="Lung and Bronchus                                "
    40="Pleura                                           "
    41="Trachea, Mediastinum and Other Respiratory Organs"
    42="Bones and Joints                                 "
    43="Soft Tissue including Heart                      "
    44="Melanoma of the Skin                             "
    45="Other Non-Epithelial Skin                        "
    46="Breast                                           "
    47="Cervix Uteri                                     "
    48="Corpus Uteri                                     "
    49="Uterus, NOS                                      "
    50="Ovary                                            "
    51="Vagina                                           "
    52="Vulva                                            "
    53="Other Female Genital Organs                      "
    54="Prostate                                         "
    55="Testis                                           "
    56="Penis                                            "
    57="Other Male Genital Organs                        "
    58="Urinary Bladder                                  "
    59="Kidney and Renal Pelvis                          "
    60="Ureter                                           "
    61="Other Urinary Organs                             "
    62="Eye and Orbit                                    "
    63="Brain                                            "
    64="Cranial Nerves Other Nervous System              "
    65="Thyroid                                          "
    66="Other Endocrine including Thymus                 "
    68="Hodgkin - Nodal                                  "
    69="Hodgkin - Extranodal                             "
    71="NHL - Nodal                                      "
    72="NHL - Extranodal                                 "
    73="Myeloma                                          "
    74="Acute Lymphocytic Leukemia                       "
    75="Chronic Lymphocytic Leukemia                     "
    76="Other Lymphocytic Leukemia                       "
    77="Acute Myeloid Leukemia                           "
    80="Acute Monocytic Leukemia                         "
    78="Chronic Myeloid Leukemia                         "
    89="Other Myeloid/Monocytic Leukemia                 "
    83="Other Acute Leukemia                             "
    85="Aleukemic, Subleukemic and NOS                   "
    86="Miscellaneous                                    ";


   DATA naaccr_data;
      infile indata lrecl=1527;
      input @5  state 2.
            @10 county 4.
            @15 race 1.
            @20 age 2.
            @25 site_rec 2.
            @30 sex 1. 
            @35 year_dx 4.
            @105 age_grp 1.;

      label age_grp='Age Recode'   
            site_rec='Site Recode'
	    year_dx='Year of Diagnosis'
	    sex = 'Sex'
	    race='Race';
            
*******************************************************************************************************************;
******** Record Uniqueness Macro - Examples;
*******************************************************************************************************************;

filename UMacro 'directory location/uniquemacro_v12'; *****insert the directory location for the file named uniquemacro_v12;
%INCLUDE UMacro/ noSOURCE;
*******************;
******** Example #1;
*******************;

%Unique(DATAIN=naaccr_data,
        UNIQ_VARS= site_rec sex race year_dx age,
	UNIQ_FMT= age age.,
        FREQ_YN=YES,                                                            
        FREQ_VARS= sex  age year_dx,
        FREQ_FMT=  sex sex. age age. year year.,
        TITLE1="Record Uniqueness Example #1 ",
        TITLE2="Age Grouped in 5 Year Categories",                                                      
        TITLE3=" ",                                                      
        TITLE4=" ",                                                     
        TITLE5=" ");                                                       

**************************************************;
******** Example #2;
******** Use format to regroup age;
**************************************************;

%Unique(DATAIN=naaccr_data,
        UNIQ_VARS= site_rec sex race year_dx age,
	UNIQ_FMT= age age_10yr.,
        FREQ_YN=YES,                                                            
        FREQ_VARS= age,
        FREQ_FMT=  age age_10yr.,
        TITLE1="Record Uniqueness Example #2 ",
        TITLE2="Age Grouped in 10 Year Categories",                                                      
        TITLE3=" ",                                                      
        TITLE4=" ",                                                     
        TITLE5=" ");                                                       


